Utils and variables (utils package)
===================================


Variables
----------------------------

.. automodule:: gadma.utils.variables
   :members: Variable, ContinuousVariable, DiscreteVariable, PopulationSizeVariable, TimeVariable, MigrationVariable, SelectionVariable, FractionVariable, Dynamic, Exp, Lin, Sud, DynamicVariable
   :undoc-members:
   :show-inheritance:


Variable Pool
---------------------------------

.. automodule:: gadma.utils.variable_pool
   :members:
   :undoc-members:
   :show-inheritance:

Distributions
--------------------------------

.. automodule:: gadma.utils.distributions
   :members:
   :undoc-members:
   :show-inheritance:

Utils
------------------------

.. automodule:: gadma.utils.utils
   :members:
   :undoc-members:
   :show-inheritance:

